Get mobile phase percentage — BAGO 0.0.1 documentation

# Get mobile phase percentage

getMobilePhasePct(gradient, timePoints)

  Function to calculate the percentage of the strong mobile phase used through the gradient, which can be used to estimate the strength of gradient.

  Parameters:

    - gradient – numpy array. Sequence of mobile phase percentages at all time points.

    - timePoints – numpy array. Sequence of time points.

  Returns:

    float. The percentage of the strong mobile phase.

To use this function:

    pctg = getMobilePhasePct(gradient, timePoints)
    print(pctg)